# SPDX-FileCopyrightText: 2018 Brent Rubell for Adafruit Industries
#
# SPDX-License-Identifier: MIT

"""
`ttn_au`
======================================================
The Things Network Frequency Plans - AU915
* Author(s): Brent Rubell
"""
TTN_FREQS = {
    0: (0xE5, 0x33, 0x5A),  # 916.8 MHz
    1: (0xE5, 0x40, 0x26),  # 917.0 MHz
    2: (0xE5, 0x4C, 0xF3),  # 917.2 MHz
    3: (0xE5, 0x59, 0xC0),  # 917.4 MHz
    4: (0xE5, 0x66, 0x8D),  # 917.6 MHz
    5: (0xE5, 0x73, 0x5A),  # 917.8 MHz
    6: (0xE5, 0x80, 0x27),  # 918.0 MHz
    7: (0xE5, 0x8C, 0xF3),
}  # 918.2 MHz
